==> dualword-rt_0.2.5.orig.tar.gz: dualword-rt-0.2.5/tr/tr_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Вкл./Выкл. Полноэкранный режим</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Press P or Q to start...</source>
        <translation>Нажмите P или Q чтобы начать...</translation>
    </message>
    <message>
        <source>Press 2 buttons (P and Q) when you see a yellow circle...</source>
        <translation>Нажмите 2 кнопки (P и Q) когда увидите жёлтый круг...</translation>
    </message>
    <message>
        <source>Reaction time: Left hand = </source>
        <translation>Время реакции: Левая рука = </translation>
    </message>
    <message>
        <source>Right hand = </source>
        <translation>Правая рука = </translation>
    </message>
    <message>
        <source>               Press P or Q to continue.
</source>
        <translation>               Нажмите P или Q чтобы продолжить.
</translation>
    </message>
    <message>
        <source>Attempts:</source>
        <translation> Попытки:</translation>
    </message>
    <message>
        <source> Min:</source>
        <translation> Мин:</translation>
    </message>
    <message>
        <source> Max:</source>
        <translation> Макс:</translation>
    </message>
    <message>
        <source> Average:</source>
        <translation> Среднее:</translation>
    </message>
    <message>
        <source> (L/R)</source>
        <translation> (Лев./Пр.)</translation>
    </message>
    <message>
        <source>Error.
Press P or Q to continue...</source>
        <translation>Ошибка.
Нажмите P или Q чтобы продолжить...</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Языки</translation>
    </message>
</context>
</TS>

==> dualword-rt_0.3.1.orig.tar.gz: dualword-rt-0.3.1/tr/tr_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Вкл./Выкл. Полноэкранный режим</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Press P or Q to start...</source>
        <translation>Нажмите P или Q чтобы начать...</translation>
    </message>
    <message>
        <source>Press 2 buttons (P and Q) when you see a yellow circle...</source>
        <translation>Нажмите 2 кнопки (P и Q) когда увидите жёлтый круг...</translation>
    </message>
    <message>
        <source>Reaction time: Left hand = </source>
        <translation>Время реакции: Левая рука = </translation>
    </message>
    <message>
        <source>Right hand = </source>
        <translation>Правая рука = </translation>
    </message>
    <message>
        <source>               Press P or Q to continue.
</source>
        <translation>               Нажмите P или Q чтобы продолжить.
</translation>
    </message>
    <message>
        <source>Attempts:</source>
        <translation> Попытки:</translation>
    </message>
    <message>
        <source> Min:</source>
        <translation> Мин:</translation>
    </message>
    <message>
        <source> Max:</source>
        <translation> Макс:</translation>
    </message>
    <message>
        <source> Average:</source>
        <translation> Среднее:</translation>
    </message>
    <message>
        <source> (L/R)</source>
        <translation> (Лев./Пр.)</translation>
    </message>
    <message>
        <source>Error.
Press P or Q to continue...</source>
        <translation>Ошибка.
Нажмите P или Q чтобы продолжить...</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Языки</translation>
    </message>
    <message>
        <source>New language will be available after a restart.</source>
        <translation>Новый язык будет доступен после перезапуска.</translation>
    </message>
</context>
</TS>
